# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/common/v1/common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/common/v1/common.proto',
  package='github.com.metaprov.modelaapi.services.common.v1',
  syntax='proto3',
  serialized_options=b'Z0github.com/metaprov/modelaapi/services/common/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n=github.com/metaprov/modelaapi/services/common/v1/common.proto\x12\x30github.com.metaprov.modelaapi.services.common.v1\"\xb6\x02\n\x0e\x44\x61tasetProfile\x12\x0c\n\x04\x63ols\x18\x01 \x01(\x05\x12\x0c\n\x04rows\x18\x02 \x01(\x05\x12\x10\n\x08\x66ilesize\x18\x03 \x01(\x05\x12\x11\n\timbalance\x18\x04 \x01(\x08\x12\x45\n\x05plots\x18\x05 \x03(\x0b\x32\x36.github.com.metaprov.modelaapi.services.common.v1.Plot\x12P\n\x07\x63olumns\x18\x06 \x03(\x0b\x32?.github.com.metaprov.modelaapi.services.common.v1.ColumnProfile\x12J\n\x05table\x18\x07 \x01(\x0b\x32;.github.com.metaprov.modelaapi.services.common.v1.TableView\"c\n\x0cModelProfile\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x45\n\x05plots\x18\x02 \x03(\x0b\x32\x36.github.com.metaprov.modelaapi.services.common.v1.Plot\"f\n\x0f\x46orecastProfile\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x45\n\x05plots\x18\x02 \x03(\x0b\x32\x36.github.com.metaprov.modelaapi.services.common.v1.Plot\"\xa5\x01\n\x0cStudyProfile\x12\x45\n\x05plots\x18\x01 \x03(\x0b\x32\x36.github.com.metaprov.modelaapi.services.common.v1.Plot\x12N\n\x06models\x18\x02 \x03(\x0b\x32>.github.com.metaprov.modelaapi.services.common.v1.ModelProfile\"L\n\x04Plot\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0b\n\x03img\x18\x03 \x01(\x0c\x12\r\n\x05\x66name\x18\x04 \x01(\t\x12\x0b\n\x03url\x18\x05 \x01(\t\"\xe6\x03\n\rColumnProfile\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\t\n\x01n\x18\x02 \x01(\x05\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x0f\n\x07missing\x18\x04 \x01(\x05\x12\x10\n\x08\x64istinct\x18\x05 \x01(\x05\x12\x0c\n\x04mean\x18\x06 \x01(\x01\x12\x0b\n\x03std\x18\x07 \x01(\x01\x12\x10\n\x08variance\x18\x08 \x01(\x01\x12\x0b\n\x03min\x18\t \x01(\x01\x12\x0b\n\x03max\x18\n \x01(\x01\x12\x10\n\x08kurtosis\x18\x0b \x01(\x01\x12\x10\n\x08skewness\x18\x0c \x01(\x01\x12\x0b\n\x03sum\x18\r \x01(\x01\x12\x0b\n\x03mad\x18\x0e \x01(\x01\x12\r\n\x05zeros\x18\x0f \x01(\x01\x12\x0b\n\x03p25\x18\x10 \x01(\x01\x12\x0b\n\x03p50\x18\x11 \x01(\x01\x12\x0b\n\x03p75\x18\x12 \x01(\x01\x12\x0c\n\x04p100\x18\x14 \x01(\x01\x12\x0b\n\x03iqr\x18\x15 \x01(\x01\x12\n\n\x02\x63v\x18\x16 \x01(\x01\x12\x11\n\tp_missing\x18\x17 \x01(\x01\x12\x0b\n\x03top\x18\x18 \x01(\x05\x12\x0c\n\x04\x66req\x18\x19 \x01(\x05\x12\x0e\n\x06ignore\x18\x1a \x01(\x08\x12\r\n\x05label\x18\x1b \x01(\x08\x12\x0c\n\x04\x63orr\x18\x1c \x01(\x08\x12N\n\thistogram\x18\x1d \x01(\x0b\x32;.github.com.metaprov.modelaapi.services.common.v1.Histogram\")\n\x0eHistogramValue\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\t\n\x01v\x18\x02 \x01(\x02\"]\n\tHistogram\x12P\n\x06values\x18\x01 \x03(\x0b\x32@.github.com.metaprov.modelaapi.services.common.v1.HistogramValue\"\xf6\x02\n\rNamespaceInfo\x12[\n\x04type\x18\x01 \x01(\x0e\x32M.github.com.metaprov.modelaapi.services.common.v1.NamespaceInfo.NamespaceType\x12\x0c\n\x04Name\x18\x02 \x01(\t\x12\x10\n\x08\x61\x63\x63ounts\x18\x03 \x01(\x05\x12\x0f\n\x07\x62uckets\x18\x04 \x01(\x05\x12\x0c\n\x04labs\x18\x05 \x01(\x05\x12\x14\n\x0cservingsites\x18\x06 \x01(\x05\x12\x10\n\x08\x64\x61tasets\x18\x07 \x01(\x05\x12\x13\n\x0b\x64\x61tasources\x18\x08 \x01(\x05\x12\x0f\n\x07studies\x18\t \x01(\x05\x12\x0e\n\x06models\x18\n \x01(\x05\"k\n\rNamespaceType\x12\n\n\x06TENANT\x10\x00\x12\x0f\n\x0b\x44\x41TAPRODUCT\x10\x01\x12\x07\n\x03LAB\x10\x02\x12\x0f\n\x0bSERVINGSITE\x10\x03\x12\x10\n\x0cMODELASYSTEM\x10\x04\x12\x11\n\rMODELACATALOG\x10\x05\"\xba\x01\n\tTableView\x12\x0c\n\x04\x63ols\x18\x01 \x03(\t\x12L\n\x04rows\x18\x02 \x03(\x0b\x32>.github.com.metaprov.modelaapi.services.common.v1.TableViewRow\x12Q\n\x08profiles\x18\x03 \x03(\x0b\x32?.github.com.metaprov.modelaapi.services.common.v1.ColumnProfile\"\x1e\n\x0cTableViewRow\x12\x0e\n\x06values\x18\x01 \x03(\tB2Z0github.com/metaprov/modelaapi/services/common/v1b\x06proto3'
)



_NAMESPACEINFO_NAMESPACETYPE = _descriptor.EnumDescriptor(
  name='NamespaceType',
  full_name='github.com.metaprov.modelaapi.services.common.v1.NamespaceInfo.NamespaceType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TENANT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DATAPRODUCT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LAB', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SERVINGSITE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MODELASYSTEM', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MODELACATALOG', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1774,
  serialized_end=1881,
)
_sym_db.RegisterEnumDescriptor(_NAMESPACEINFO_NAMESPACETYPE)


_DATASETPROFILE = _descriptor.Descriptor(
  name='DatasetProfile',
  full_name='github.com.metaprov.modelaapi.services.common.v1.DatasetProfile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cols', full_name='github.com.metaprov.modelaapi.services.common.v1.DatasetProfile.cols', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rows', full_name='github.com.metaprov.modelaapi.services.common.v1.DatasetProfile.rows', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filesize', full_name='github.com.metaprov.modelaapi.services.common.v1.DatasetProfile.filesize', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='imbalance', full_name='github.com.metaprov.modelaapi.services.common.v1.DatasetProfile.imbalance', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plots', full_name='github.com.metaprov.modelaapi.services.common.v1.DatasetProfile.plots', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='columns', full_name='github.com.metaprov.modelaapi.services.common.v1.DatasetProfile.columns', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='table', full_name='github.com.metaprov.modelaapi.services.common.v1.DatasetProfile.table', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=116,
  serialized_end=426,
)


_MODELPROFILE = _descriptor.Descriptor(
  name='ModelProfile',
  full_name='github.com.metaprov.modelaapi.services.common.v1.ModelProfile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.common.v1.ModelProfile.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plots', full_name='github.com.metaprov.modelaapi.services.common.v1.ModelProfile.plots', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=428,
  serialized_end=527,
)


_FORECASTPROFILE = _descriptor.Descriptor(
  name='ForecastProfile',
  full_name='github.com.metaprov.modelaapi.services.common.v1.ForecastProfile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.common.v1.ForecastProfile.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plots', full_name='github.com.metaprov.modelaapi.services.common.v1.ForecastProfile.plots', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=529,
  serialized_end=631,
)


_STUDYPROFILE = _descriptor.Descriptor(
  name='StudyProfile',
  full_name='github.com.metaprov.modelaapi.services.common.v1.StudyProfile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='plots', full_name='github.com.metaprov.modelaapi.services.common.v1.StudyProfile.plots', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='models', full_name='github.com.metaprov.modelaapi.services.common.v1.StudyProfile.models', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=634,
  serialized_end=799,
)


_PLOT = _descriptor.Descriptor(
  name='Plot',
  full_name='github.com.metaprov.modelaapi.services.common.v1.Plot',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.common.v1.Plot.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='github.com.metaprov.modelaapi.services.common.v1.Plot.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='img', full_name='github.com.metaprov.modelaapi.services.common.v1.Plot.img', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fname', full_name='github.com.metaprov.modelaapi.services.common.v1.Plot.fname', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='url', full_name='github.com.metaprov.modelaapi.services.common.v1.Plot.url', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=801,
  serialized_end=877,
)


_COLUMNPROFILE = _descriptor.Descriptor(
  name='ColumnProfile',
  full_name='github.com.metaprov.modelaapi.services.common.v1.ColumnProfile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.common.v1.ColumnProfile.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='n', full_name='github.com.metaprov.modelaapi.services.common.v1.ColumnProfile.n', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='github.com.metaprov.modelaapi.services.common.v1.ColumnProfile.type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='missing', full_name='github.com.metaprov.modelaapi.services.common.v1.ColumnProfile.missing', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distinct', full_name='github.com.metaprov.modelaapi.services.common.v1.ColumnProfile.distinct', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mean', full_name='github.com.metaprov.modelaapi.services.common.v1.ColumnProfile.mean', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='std', full_name='github.com.metaprov.modelaapi.services.common.v1.ColumnProfile.std', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variance', full_name='github.com.metaprov.modelaapi.services.common.v1.ColumnProfile.variance', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min', full_name='github.com.metaprov.modelaapi.services.common.v1.ColumnProfile.min', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max', full_name='github.com.metaprov.modelaapi.services.common.v1.ColumnProfile.max', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kurtosis', full_name='github.com.metaprov.modelaapi.services.common.v1.ColumnProfile.kurtosis', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='skewness', full_name='github.com.metaprov.modelaapi.services.common.v1.ColumnProfile.skewness', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sum', full_name='github.com.metaprov.modelaapi.services.common.v1.ColumnProfile.sum', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mad', full_name='github.com.metaprov.modelaapi.services.common.v1.ColumnProfile.mad', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zeros', full_name='github.com.metaprov.modelaapi.services.common.v1.ColumnProfile.zeros', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='p25', full_name='github.com.metaprov.modelaapi.services.common.v1.ColumnProfile.p25', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='p50', full_name='github.com.metaprov.modelaapi.services.common.v1.ColumnProfile.p50', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='p75', full_name='github.com.metaprov.modelaapi.services.common.v1.ColumnProfile.p75', index=17,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='p100', full_name='github.com.metaprov.modelaapi.services.common.v1.ColumnProfile.p100', index=18,
      number=20, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='iqr', full_name='github.com.metaprov.modelaapi.services.common.v1.ColumnProfile.iqr', index=19,
      number=21, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cv', full_name='github.com.metaprov.modelaapi.services.common.v1.ColumnProfile.cv', index=20,
      number=22, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='p_missing', full_name='github.com.metaprov.modelaapi.services.common.v1.ColumnProfile.p_missing', index=21,
      number=23, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='top', full_name='github.com.metaprov.modelaapi.services.common.v1.ColumnProfile.top', index=22,
      number=24, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='freq', full_name='github.com.metaprov.modelaapi.services.common.v1.ColumnProfile.freq', index=23,
      number=25, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ignore', full_name='github.com.metaprov.modelaapi.services.common.v1.ColumnProfile.ignore', index=24,
      number=26, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label', full_name='github.com.metaprov.modelaapi.services.common.v1.ColumnProfile.label', index=25,
      number=27, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='corr', full_name='github.com.metaprov.modelaapi.services.common.v1.ColumnProfile.corr', index=26,
      number=28, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='histogram', full_name='github.com.metaprov.modelaapi.services.common.v1.ColumnProfile.histogram', index=27,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=880,
  serialized_end=1366,
)


_HISTOGRAMVALUE = _descriptor.Descriptor(
  name='HistogramValue',
  full_name='github.com.metaprov.modelaapi.services.common.v1.HistogramValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.common.v1.HistogramValue.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='v', full_name='github.com.metaprov.modelaapi.services.common.v1.HistogramValue.v', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1368,
  serialized_end=1409,
)


_HISTOGRAM = _descriptor.Descriptor(
  name='Histogram',
  full_name='github.com.metaprov.modelaapi.services.common.v1.Histogram',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='github.com.metaprov.modelaapi.services.common.v1.Histogram.values', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1411,
  serialized_end=1504,
)


_NAMESPACEINFO = _descriptor.Descriptor(
  name='NamespaceInfo',
  full_name='github.com.metaprov.modelaapi.services.common.v1.NamespaceInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='github.com.metaprov.modelaapi.services.common.v1.NamespaceInfo.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Name', full_name='github.com.metaprov.modelaapi.services.common.v1.NamespaceInfo.Name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accounts', full_name='github.com.metaprov.modelaapi.services.common.v1.NamespaceInfo.accounts', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='buckets', full_name='github.com.metaprov.modelaapi.services.common.v1.NamespaceInfo.buckets', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labs', full_name='github.com.metaprov.modelaapi.services.common.v1.NamespaceInfo.labs', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='servingsites', full_name='github.com.metaprov.modelaapi.services.common.v1.NamespaceInfo.servingsites', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datasets', full_name='github.com.metaprov.modelaapi.services.common.v1.NamespaceInfo.datasets', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datasources', full_name='github.com.metaprov.modelaapi.services.common.v1.NamespaceInfo.datasources', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='studies', full_name='github.com.metaprov.modelaapi.services.common.v1.NamespaceInfo.studies', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='models', full_name='github.com.metaprov.modelaapi.services.common.v1.NamespaceInfo.models', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _NAMESPACEINFO_NAMESPACETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1507,
  serialized_end=1881,
)


_TABLEVIEW = _descriptor.Descriptor(
  name='TableView',
  full_name='github.com.metaprov.modelaapi.services.common.v1.TableView',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cols', full_name='github.com.metaprov.modelaapi.services.common.v1.TableView.cols', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rows', full_name='github.com.metaprov.modelaapi.services.common.v1.TableView.rows', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='profiles', full_name='github.com.metaprov.modelaapi.services.common.v1.TableView.profiles', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1884,
  serialized_end=2070,
)


_TABLEVIEWROW = _descriptor.Descriptor(
  name='TableViewRow',
  full_name='github.com.metaprov.modelaapi.services.common.v1.TableViewRow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='github.com.metaprov.modelaapi.services.common.v1.TableViewRow.values', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2072,
  serialized_end=2102,
)

_DATASETPROFILE.fields_by_name['plots'].message_type = _PLOT
_DATASETPROFILE.fields_by_name['columns'].message_type = _COLUMNPROFILE
_DATASETPROFILE.fields_by_name['table'].message_type = _TABLEVIEW
_MODELPROFILE.fields_by_name['plots'].message_type = _PLOT
_FORECASTPROFILE.fields_by_name['plots'].message_type = _PLOT
_STUDYPROFILE.fields_by_name['plots'].message_type = _PLOT
_STUDYPROFILE.fields_by_name['models'].message_type = _MODELPROFILE
_COLUMNPROFILE.fields_by_name['histogram'].message_type = _HISTOGRAM
_HISTOGRAM.fields_by_name['values'].message_type = _HISTOGRAMVALUE
_NAMESPACEINFO.fields_by_name['type'].enum_type = _NAMESPACEINFO_NAMESPACETYPE
_NAMESPACEINFO_NAMESPACETYPE.containing_type = _NAMESPACEINFO
_TABLEVIEW.fields_by_name['rows'].message_type = _TABLEVIEWROW
_TABLEVIEW.fields_by_name['profiles'].message_type = _COLUMNPROFILE
DESCRIPTOR.message_types_by_name['DatasetProfile'] = _DATASETPROFILE
DESCRIPTOR.message_types_by_name['ModelProfile'] = _MODELPROFILE
DESCRIPTOR.message_types_by_name['ForecastProfile'] = _FORECASTPROFILE
DESCRIPTOR.message_types_by_name['StudyProfile'] = _STUDYPROFILE
DESCRIPTOR.message_types_by_name['Plot'] = _PLOT
DESCRIPTOR.message_types_by_name['ColumnProfile'] = _COLUMNPROFILE
DESCRIPTOR.message_types_by_name['HistogramValue'] = _HISTOGRAMVALUE
DESCRIPTOR.message_types_by_name['Histogram'] = _HISTOGRAM
DESCRIPTOR.message_types_by_name['NamespaceInfo'] = _NAMESPACEINFO
DESCRIPTOR.message_types_by_name['TableView'] = _TABLEVIEW
DESCRIPTOR.message_types_by_name['TableViewRow'] = _TABLEVIEWROW
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DatasetProfile = _reflection.GeneratedProtocolMessageType('DatasetProfile', (_message.Message,), {
  'DESCRIPTOR' : _DATASETPROFILE,
  '__module__' : 'github.com.metaprov.modelaapi.services.common.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.common.v1.DatasetProfile)
  })
_sym_db.RegisterMessage(DatasetProfile)

ModelProfile = _reflection.GeneratedProtocolMessageType('ModelProfile', (_message.Message,), {
  'DESCRIPTOR' : _MODELPROFILE,
  '__module__' : 'github.com.metaprov.modelaapi.services.common.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.common.v1.ModelProfile)
  })
_sym_db.RegisterMessage(ModelProfile)

ForecastProfile = _reflection.GeneratedProtocolMessageType('ForecastProfile', (_message.Message,), {
  'DESCRIPTOR' : _FORECASTPROFILE,
  '__module__' : 'github.com.metaprov.modelaapi.services.common.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.common.v1.ForecastProfile)
  })
_sym_db.RegisterMessage(ForecastProfile)

StudyProfile = _reflection.GeneratedProtocolMessageType('StudyProfile', (_message.Message,), {
  'DESCRIPTOR' : _STUDYPROFILE,
  '__module__' : 'github.com.metaprov.modelaapi.services.common.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.common.v1.StudyProfile)
  })
_sym_db.RegisterMessage(StudyProfile)

Plot = _reflection.GeneratedProtocolMessageType('Plot', (_message.Message,), {
  'DESCRIPTOR' : _PLOT,
  '__module__' : 'github.com.metaprov.modelaapi.services.common.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.common.v1.Plot)
  })
_sym_db.RegisterMessage(Plot)

ColumnProfile = _reflection.GeneratedProtocolMessageType('ColumnProfile', (_message.Message,), {
  'DESCRIPTOR' : _COLUMNPROFILE,
  '__module__' : 'github.com.metaprov.modelaapi.services.common.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.common.v1.ColumnProfile)
  })
_sym_db.RegisterMessage(ColumnProfile)

HistogramValue = _reflection.GeneratedProtocolMessageType('HistogramValue', (_message.Message,), {
  'DESCRIPTOR' : _HISTOGRAMVALUE,
  '__module__' : 'github.com.metaprov.modelaapi.services.common.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.common.v1.HistogramValue)
  })
_sym_db.RegisterMessage(HistogramValue)

Histogram = _reflection.GeneratedProtocolMessageType('Histogram', (_message.Message,), {
  'DESCRIPTOR' : _HISTOGRAM,
  '__module__' : 'github.com.metaprov.modelaapi.services.common.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.common.v1.Histogram)
  })
_sym_db.RegisterMessage(Histogram)

NamespaceInfo = _reflection.GeneratedProtocolMessageType('NamespaceInfo', (_message.Message,), {
  'DESCRIPTOR' : _NAMESPACEINFO,
  '__module__' : 'github.com.metaprov.modelaapi.services.common.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.common.v1.NamespaceInfo)
  })
_sym_db.RegisterMessage(NamespaceInfo)

TableView = _reflection.GeneratedProtocolMessageType('TableView', (_message.Message,), {
  'DESCRIPTOR' : _TABLEVIEW,
  '__module__' : 'github.com.metaprov.modelaapi.services.common.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.common.v1.TableView)
  })
_sym_db.RegisterMessage(TableView)

TableViewRow = _reflection.GeneratedProtocolMessageType('TableViewRow', (_message.Message,), {
  'DESCRIPTOR' : _TABLEVIEWROW,
  '__module__' : 'github.com.metaprov.modelaapi.services.common.v1.common_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.common.v1.TableViewRow)
  })
_sym_db.RegisterMessage(TableViewRow)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
